@@ -22,7 +22,7 @@
 #include <pthread.h>
 #endif
 
-#define VERSION "7.266"
+#define VERSION "7.270"
 #define SHOWVERSION reporterr( "%s (%s) Version " VERSION " alg=%c, model=%s, amax=%3.1f\n%d thread(s)\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
@@ -56,17 +56,19 @@
 
 extern char modelname[500];
 extern int njob, nlenmax;
-extern int amino_n[0x80];
-extern char amino_grp[0x80];
-extern int amino_dis[0x80][0x80];
+extern int amino_n[0x100];
+extern char amino_grp[0x100];
+//extern int amino_dis[0x100][0x100];
+extern int **amino_dis;
 extern double **n_disLN;
-extern double amino_dis_consweight_multi[0x80][0x80];
+//extern double amino_dis_consweight_multi[0x100][0x100];
+extern double **amino_dis_consweight_multi;
 extern int **n_dis;
 extern int **n_disFFT;
 extern double **n_dis_consweight_multi;
-extern char amino[0x80];
-extern double polarity[0x80];
-extern double volume[0x80];
+extern unsigned char amino[0x100];
+extern double polarity[0x100];
+extern double volume[0x100];
 extern int ribosumdis[37][37];
 
 extern int ppid;
